==> igniteui-react-charts-16.6.8.tgz: package/ES2015/MovingAverageConvergenceDivergenceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { MovingAverageConvergenceDivergenceIndicatorStrategy } from "./MovingAverageConvergenceDivergenceIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
import { Brush } from "igniteui-react-core/ES2015/Brush";
/**
 * @hidden
 */
export class MovingAverageConvergenceDivergenceIndicator extends StrategyBasedIndicator {
    constructor() {
        super();
        this.trendLineBrush = ((() => {
            let $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        this.trendLineType = 10;
        this.trendLinePeriod = 9;
        this.pd = 1;
    }
    get_p5() {
        return new MovingAverageConvergenceDivergenceIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return MovingAverageConvergenceDivergenceIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get shortPeriod() {
        return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.qt));
    }
    set shortPeriod(a) {
        this.h(MovingAverageConvergenceDivergenceIndicator.qt, a);
    }
    qd() {
        return this.shortPeriod;
    }
    get longPeriod() {
        return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.qs));
    }
    set longPeriod(a) {
        this.h(MovingAverageConvergenceDivergenceIndicator.qs, a);
    }
    qa() {
        return this.longPeriod;
    }
    get signalPeriod() {
        return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.qu));
    }
    set signalPeriod(a) {
        this.h(MovingAverageConvergenceDivergenceIndicator.qu, a);
    }
    pl() {
        return this.signalPeriod;
    }
}
MovingAverageConvergenceDivergenceIndicator.$t = markType(MovingAverageConvergenceDivergenceIndicator, 'MovingAverageConvergenceDivergenceIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
MovingAverageConvergenceDivergenceIndicator.qt = StrategyBasedIndicator.qp(10, MovingAverageConvergenceDivergenceIndicator.$);
MovingAverageConvergenceDivergenceIndicator.qs = StrategyBasedIndicator.ql(30, MovingAverageConvergenceDivergenceIndicator.$);
MovingAverageConvergenceDivergenceIndicator.qu = StrategyBasedIndicator.qo(9, MovingAverageConvergenceDivergenceIndicator.$, "SignalPeriod");

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/MovingAverageConvergenceDivergenceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { MovingAverageConvergenceDivergenceIndicatorStrategy } from "./MovingAverageConvergenceDivergenceIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
import { Brush } from "igniteui-react-core/ES2015/Brush";
/**
 * @hidden
 */
export class MovingAverageConvergenceDivergenceIndicator extends StrategyBasedIndicator {
    constructor() {
        super();
        this.trendLineBrush = ((() => {
            let $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        this.trendLineType = 10;
        this.trendLinePeriod = 9;
        this.pk = 1;
    }
    get_qc() {
        return new MovingAverageConvergenceDivergenceIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return MovingAverageConvergenceDivergenceIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get shortPeriod() {
        return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.q0));
    }
    set shortPeriod(a) {
        this.h(MovingAverageConvergenceDivergenceIndicator.q0, a);
    }
    qk() {
        return this.shortPeriod;
    }
    get longPeriod() {
        return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.qz));
    }
    set longPeriod(a) {
        this.h(MovingAverageConvergenceDivergenceIndicator.qz, a);
    }
    qh() {
        return this.longPeriod;
    }
    get signalPeriod() {
        return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.q1));
    }
    set signalPeriod(a) {
        this.h(MovingAverageConvergenceDivergenceIndicator.q1, a);
    }
    ps() {
        return this.signalPeriod;
    }
}
MovingAverageConvergenceDivergenceIndicator.$t = markType(MovingAverageConvergenceDivergenceIndicator, 'MovingAverageConvergenceDivergenceIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
MovingAverageConvergenceDivergenceIndicator.q0 = StrategyBasedIndicator.qw(10, MovingAverageConvergenceDivergenceIndicator.$);
MovingAverageConvergenceDivergenceIndicator.qz = StrategyBasedIndicator.qs(30, MovingAverageConvergenceDivergenceIndicator.$);
MovingAverageConvergenceDivergenceIndicator.q1 = StrategyBasedIndicator.qv(9, MovingAverageConvergenceDivergenceIndicator.$, "SignalPeriod");
